@@ -18,6 +18,7 @@
 */
 
 #include "kmahjonggbackground.h"
+#include "libkmahjongg_debug.h"
 
 #include <KLocalizedString>
 #include <kconfig.h>
@@ -29,7 +30,6 @@
 #include <QPixmap>
 #include <QPixmapCache>
 #include <QPainter>
-#include "libkmahjong_debug.h"
 
 class KMahjonggBackgroundPrivate
 {
@@ -73,10 +73,11 @@ KMahjonggBackground::~KMahjonggBackground() {
 
 bool KMahjonggBackground::loadDefault()
 {
-    QLatin1String idx( "default.desktop" );
+    // Set default background here.
+    QLatin1String idx( "egyptian.desktop" );
 
     QString bgPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kmahjongglib/backgrounds/" + idx);
-    qCDebug(LIBKMAHJONG_LOG) << "Inside LoadDefault(), located background at" << bgPath;
+    qCDebug(LIBKMAHJONGG_LOG) << "Inside LoadDefault(), located background at" << bgPath;
     if (bgPath.isEmpty()) {
         return false;
     }
@@ -86,10 +87,10 @@ bool KMahjonggBackground::loadDefault()
 #define kBGVersionFormat 1
 
 bool KMahjonggBackground::load(const QString &file, short width, short height) {
-    //qCDebug(LIBKMAHJONG_LOG) << "Background loading";
+    //qCDebug(LIBKMAHJONGG_LOG) << "Background loading";
     d->isSVG = false;
 
-    //qCDebug(LIBKMAHJONG_LOG) << "Attempting to load .desktop at" << file;
+    //qCDebug(LIBKMAHJONGG_LOG) << "Attempting to load .desktop at" << file;
 
     // verify if it is a valid file first and if we can open it
     QFile bgfile(file);
@@ -117,7 +118,7 @@ bool KMahjonggBackground::load(const QString &file, short width, short height) {
     }
 
     if (d->isPlain) {
-        //qCDebug(LIBKMAHJONG_LOG) << "Using plain background";
+        //qCDebug(LIBKMAHJONGG_LOG) << "Using plain background";
         d->graphicspath.clear();
         d->filename = file;
         return true;
@@ -127,7 +128,7 @@ bool KMahjonggBackground::load(const QString &file, short width, short height) {
 
     d->graphicspath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kmahjongglib/backgrounds/" + graphName);
 
-    qCDebug(LIBKMAHJONG_LOG) << "Using background at" << d->graphicspath;
+    qCDebug(LIBKMAHJONGG_LOG) << "Using background at" << d->graphicspath;
 
     if (d->graphicspath.isEmpty()) return (false);
 
@@ -152,7 +153,7 @@ bool KMahjonggBackground::loadGraphics() {
     if (d->svg.isValid()) {
         d->isSVG = true;
     } else {
-        //qCDebug(LIBKMAHJONG_LOG) << "could not load svg";
+        //qCDebug(LIBKMAHJONGG_LOG) << "could not load svg";
         return( false );
     }
     return (true);
